==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AssigningShapeStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningShapeStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningShapeStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningShapeStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningShapeStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningShapeStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningShapeStyleEventArgsBaseDescriptionMetadata.c(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.j(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningShapeStyleEventArgsBaseDescriptionMetadata.b(a);
        a.z("AssigningShapeStyleEventArgsBase", AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningShapeStyleEventArgsBaseDescriptionMetadata, 'AssigningShapeStyleEventArgsBaseDescriptionMetadata');
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningShapeStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningShapeStyleEventArgsBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AssigningShapeStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningShapeStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningShapeStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningShapeStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningShapeStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningShapeStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningShapeStyleEventArgsBaseDescriptionMetadata.c(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.k(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningShapeStyleEventArgsBaseDescriptionMetadata.b(a);
        a.ab("AssigningShapeStyleEventArgsBase", AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningShapeStyleEventArgsBaseDescriptionMetadata, 'AssigningShapeStyleEventArgsBaseDescriptionMetadata');
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningShapeStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningShapeStyleEventArgsBaseDescriptionMetadata };
